<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-CN" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+111"/>
      <source>Reverse Engineering</source>
      <translation>逆向工程</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>近似​​平面...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>近似​​平面</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-62"/>
      <source>Reverse Engineering</source>
      <translation>逆向工程</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate surface...</source>
      <translation>近似曲面...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-Spline surface</source>
      <translation>近似B样条曲面</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation>逆向工程</translation>
    </message>
  </context>
</TS>
